(function(){
var c$ = Clazz.declareInterface(java.util, "Map");
Clazz.declareInterface(java.util.Map, "Entry");
c$.NOT_SIMPLE = 0;
c$.INVALID_KEY = 1;
c$.NO_SUCH_KEY = 2;
c$.HAS_KEY = 3;
})();
;//5.0.1-v7 Mon May 12 23:42:45 CDT 2025
